"use client";

import { useState } from "react";
import Link from "next/link";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { 
  Table, 
  TableBody, 
  TableCell, 
  TableHead, 
  TableHeader, 
  TableRow 
} from "@/components/ui/table";
import { 
  DropdownMenu, 
  DropdownMenuContent, 
  DropdownMenuItem, 
  DropdownMenuLabel, 
  DropdownMenuSeparator, 
  DropdownMenuTrigger 
} from "@/components/ui/dropdown-menu";
import { 
  PlusCircle, 
  Search, 
  MoreHorizontal, 
  Pencil, 
  Trash2, 
  Users
} from "lucide-react";
import { Badge } from "@/components/ui/badge";

export default function TagsPage() {
  const [searchQuery, setSearchQuery] = useState("");

  // Mock data for tags
  const tags = [
    {
      id: 1,
      name: "Frontend",
      description: "Développement frontend",
      color: "blue",
      persons: 12,
    },
    {
      id: 2,
      name: "Backend",
      description: "Développement backend",
      color: "green",
      persons: 8,
    },
    {
      id: 3,
      name: "Fullstack",
      description: "Développement fullstack",
      color: "purple",
      persons: 5,
    },
    {
      id: 4,
      name: "UX/UI",
      description: "Design UX/UI",
      color: "pink",
      persons: 3,
    },
    {
      id: 5,
      name: "DevOps",
      description: "Infrastructure et déploiement",
      color: "orange",
      persons: 2,
    },
    {
      id: 6,
      name: "Junior",
      description: "Niveau junior",
      color: "yellow",
      persons: 7,
    },
    {
      id: 7,
      name: "Medior",
      description: "Niveau intermédiaire",
      color: "amber",
      persons: 5,
    },
    {
      id: 8,
      name: "Senior",
      description: "Niveau senior",
      color: "red",
      persons: 6,
    },
  ];

  // Map color names to Tailwind classes
  const colorMap: Record<string, string> = {
    blue: "bg-blue-100 text-blue-800 dark:bg-blue-900 dark:text-blue-300",
    green: "bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-300",
    purple: "bg-purple-100 text-purple-800 dark:bg-purple-900 dark:text-purple-300",
    pink: "bg-pink-100 text-pink-800 dark:bg-pink-900 dark:text-pink-300",
    orange: "bg-orange-100 text-orange-800 dark:bg-orange-900 dark:text-orange-300",
    yellow: "bg-yellow-100 text-yellow-800 dark:bg-yellow-900 dark:text-yellow-300",
    amber: "bg-amber-100 text-amber-800 dark:bg-amber-900 dark:text-amber-300",
    red: "bg-red-100 text-red-800 dark:bg-red-900 dark:text-red-300",
  };

  // Filter tags based on search query
  const filteredTags = tags.filter(
    (tag) =>
      tag.name.toLowerCase().includes(searchQuery.toLowerCase()) ||
      tag.description.toLowerCase().includes(searchQuery.toLowerCase())
  );

  return (
    <div className="flex flex-col gap-6">
      <div className="flex items-center justify-between">
        <h1 className="text-3xl font-bold">Tags</h1>
        <div className="flex gap-2">
          <Button variant="outline" asChild>
            <Link href="/tags/demo">
              Démo sélecteur
            </Link>
          </Button>
          <Button asChild>
            <Link href="/tags/new">
              <PlusCircle className="mr-2 h-4 w-4" />
              Nouveau tag
            </Link>
          </Button>
        </div>
      </div>

      <div className="flex items-center gap-2">
        <div className="relative flex-1">
          <Search className="absolute left-2.5 top-2.5 h-4 w-4 text-muted-foreground" />
          <Input
            type="search"
            placeholder="Rechercher des tags..."
            className="pl-8"
            value={searchQuery}
            onChange={(e) => setSearchQuery(e.target.value)}
          />
        </div>
      </div>

      <div className="rounded-md border">
        <Table>
          <TableHeader>
            <TableRow>
              <TableHead>Nom</TableHead>
              <TableHead>Description</TableHead>
              <TableHead>Personnes</TableHead>
              <TableHead className="w-[100px]">Actions</TableHead>
            </TableRow>
          </TableHeader>
          <TableBody>
            {filteredTags.length === 0 ? (
              <TableRow>
                <TableCell colSpan={4} className="h-24 text-center">
                  Aucun tag trouvé.
                </TableCell>
              </TableRow>
            ) : (
              filteredTags.map((tag) => (
                <TableRow key={tag.id}>
                  <TableCell>
                    <Badge className={colorMap[tag.color]}>
                      {tag.name}
                    </Badge>
                  </TableCell>
                  <TableCell>{tag.description}</TableCell>
                  <TableCell>{tag.persons}</TableCell>
                  <TableCell>
                    <DropdownMenu>
                      <DropdownMenuTrigger asChild>
                        <Button variant="ghost" size="icon">
                          <MoreHorizontal className="h-4 w-4" />
                          <span className="sr-only">Actions</span>
                        </Button>
                      </DropdownMenuTrigger>
                      <DropdownMenuContent align="end">
                        <DropdownMenuLabel>Actions</DropdownMenuLabel>
                        <DropdownMenuSeparator />
                        <DropdownMenuItem asChild>
                          <Link href={`/tags/${tag.id}/edit`} className="flex items-center">
                            <Pencil className="mr-2 h-4 w-4" />
                            <span>Modifier</span>
                          </Link>
                        </DropdownMenuItem>
                        <DropdownMenuItem asChild>
                          <Link href={`/tags/${tag.id}/persons`} className="flex items-center">
                            <Users className="mr-2 h-4 w-4" />
                            <span>Voir les personnes</span>
                          </Link>
                        </DropdownMenuItem>
                        <DropdownMenuItem className="text-destructive focus:text-destructive">
                          <Trash2 className="mr-2 h-4 w-4" />
                          <span>Supprimer</span>
                        </DropdownMenuItem>
                      </DropdownMenuContent>
                    </DropdownMenu>
                  </TableCell>
                </TableRow>
              ))
            )}
          </TableBody>
        </Table>
      </div>
    </div>
  );
}
